@@ -19,7 +19,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: RegistryInjector.java 19966 2010-06-09 12:59:30Z alitokmen $
+ * $Id: RegistryInjector.java 20106 2010-07-22 11:45:14Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jonas.camel.component;
@@ -48,11 +48,19 @@ public class RegistryInjector {
 
     private List<String> registryFilesContent;
 
-    public RegistryInjector(final Map<String, String> replacements) throws Exception {
-        this(replacements, null);
+    public RegistryInjector() throws Exception {
+        this(null, null);
     }
 
-    public RegistryInjector(final Map<String, String> replacements, final List<String> includeXMLs) throws Exception {
+    public RegistryInjector(final Map<String, String> extraReplacements) throws Exception {
+        this(extraReplacements, null);
+    }
+
+    public RegistryInjector(final List<String> includeXMLs) throws Exception {
+        this(null, includeXMLs);
+    }
+
+    public RegistryInjector(final Map<String, String> extraReplacements, final List<String> includeXMLs) throws Exception {
         final String JONAS_BASE = System.getProperty("jonas.base");
         if (JONAS_BASE == null) {
             throw new RuntimeException("JONAS_BASE not defined");
@@ -80,8 +88,8 @@ public class RegistryInjector {
                 }
             }
         }
-        if (replacements != null) {
-            this.replacements.putAll(replacements);
+        if (extraReplacements != null) {
+            this.replacements.putAll(extraReplacements);
         }
 
         // Read all registry XML files and inject properties
@@ -126,6 +134,10 @@ public class RegistryInjector {
         }
     }
 
+    public Map<String, String> getAllReplacements() {
+        return this.replacements;
+    }
+
     public List<String> getRegistryFilesContent() {
         return this.registryFilesContent;
     }
